@@ -6,6 +6,34 @@ use HTTP::Proxy::BodyFilter;
 use vars qw( @ISA );
 @ISA = qw( HTTP::Proxy::BodyFilter );
 
+sub init {
+    croak "First parameter must be a HTML::Parser object"
+      unless $_[1]->isa('HTML::Parser');
+
+    my $self = shift;
+    $self->{_parser} = shift;
+
+    my %args = (@_);
+    $self->{rw} = delete $args{rw};
+}
+
+sub filter {
+    my ( $self, $dataref, $message, $protocol, $buffer ) = @_;
+
+    @{ $self->{_parser} }{qw( output message protocol )} =
+      ( "", $message, $protocol );
+
+    $self->{_parser}->parse($$dataref);
+    $self->{_parser}->eof if not defined $buffer;    # last chunk
+    $$dataref = $self->{_parser}{output} if $self->{rw};
+}
+
+sub will_modify { $_[0]->{rw} }
+
+1;
+
+__END__
+
 =head1 NAME
 
 HTTP::Proxy::BodyFilter::htmlparser - Filter using HTML::Parser
@@ -34,21 +62,25 @@ With a read-write filter, you B<must> recreate the whole body data. This
 is mainly due to the fact that the HTML::Parser has its own buffering
 system, and that there is no easy way to correlate the data that triggered
 the HTML::Parser event and its original position in the chunk sent by the
-origin server.
+origin server. See below for details.
+
+Note that a simple filter that modify the HTML text (not the tags) can
+be created more easily with HTTP::Proxy::BodyFilter::htmltext.
+
+=head2 Creating a HTML::Parser that rewrites pages
 
 A read-write filter is declared by passing C<rw =E<gt> 1> to the constructor:
 
      HTTP::Proxy::BodyFilter::htmlparser->new( $parser, rw => 1 );
 
-=head2 Creating a HTML::Parser that rewrites pages
+To be able to modify the body of a message, a filter created with
+HTTP::Proxy::BodyFilter::htmlparser must rewrite it completely. The
+HTML::Parser object can update a special attribute named C<output>.
+To do so, the HTML::Parser handler will have to request the C<self>
+attribute (that is to say, require access to the parser itself) and
+update its C<output> key.
 
-To be able to modify files, a filter must rewrite them completely.
-The HTML::Parser object can update a special attribute named C<output>.
-To do so, the handler will have to request the C<self> attribute
-and update its C<output> key.
-
-Other attributes are made available by this filter to the HTML::Parser
-object:
+The following attributes are added to the HTML::Parser object by this filter:
 
 =over 4
 
@@ -72,29 +104,33 @@ A reference to the HTTP::Protocol object.
 
 =back
 
-=cut
+=head1 METHODS
 
-sub init {
-    croak "First parameter must be a HTML::Parser object"
-      unless $_[1]->isa('HTML::Parser');
+This filter defines three methods, called automatically:
 
-    my $self = shift;
-    $self->{_parser} = shift;
+=over 4
 
-    my %args = (@_);
-    $self->{rw} = delete $args{rw};
-}
+=item filter()
 
-sub filter {
-    my ( $self, $dataref, $message, $protocol, $buffer ) = @_;
+The C<filter()> method handles all the interactions with the HTML::Parser
+object.
 
-    @{ $self->{_parser} }{qw( output message protocol )} =
-      ( "", $message, $protocol );
+=item init()
 
-    $self->{_parser}->parse($$dataref);
-    $self->{_parser}->eof if not defined $buffer;    # last chunk
-    $$dataref = $self->{_parser}{output} if $self->{rw};
-}
+Initialise the filter with the HTML::Parser object passed to the constructor.
+
+=item will_modify()
+
+This method returns a boolean value that indicates to the system
+if it will modify the data passing through. The value is actually
+the value of the C<rw> parameter passed to the constructor.
+
+=back
+
+=head1 SEE ALSO
+
+L<HTTP::Proxy>, L<HTTP::Proxy::Bodyfilter>,
+L<HTTP::Proxy::BodyFilter::htmltext>.
 
 =head1 AUTHOR
 
@@ -102,7 +138,7 @@ Philippe "BooK" Bruhat, E<lt>book@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2003-2004, Philippe Bruhat
+Copyright 2003-2006, Philippe Bruhat.
 
 =head1 LICENSE
 
@@ -111,4 +147,3 @@ the same terms as Perl itself.
 
 =cut
 
-1;
