@@ -6,6 +6,23 @@ use HTTP::Proxy::BodyFilter;
 use vars qw( @ISA );
 @ISA = qw( HTTP::Proxy::BodyFilter );
 
+sub filter {
+    my ( $self, $dataref, $message, $protocol, $buffer ) = @_;
+    return if not defined $buffer;    # last "tags"
+
+    my $idx = rindex( $$dataref, '<' );
+    if ( $idx > rindex( $$dataref, '>' ) ) {
+        $$buffer = substr( $$dataref, $idx );
+        $$dataref = substr( $$dataref, 0, $idx );
+    }
+}
+
+sub will_modify { 0 }
+
+1;
+
+__END__
+
 =head1 NAME
 
 HTTP::Proxy::BodyFilter::tags - A filter that outputs only complete tags
@@ -30,18 +47,27 @@ HTTP::Proxy::BodyFilter::tags - A filter that outputs only complete tags
 The HTTP::Proxy::BodyFilter::tags filter makes sure that the next filter
 in the filter chain will only receive complete tags.
 
-=cut
+=head1 METHOD
 
-sub filter {
-    my ( $self, $dataref, $message, $protocol, $buffer ) = @_;
-    return if not defined $buffer;    # last "tags"
+This class defines two methods, that are called automatically:
 
-    my $idx = rindex( $$dataref, '<' );
-    if ( $idx > rindex( $$dataref, '>' ) ) {
-        $$buffer = substr( $$dataref, $idx );
-        $$dataref = substr( $$dataref, 0, $idx );
-    }
-}
+=over 4
+
+=item filter()
+
+Buffer incomplete tags to ensure that subsequent filters will only
+receive complete HTML tags.
+
+=item will_modify()
+
+This method returns a I<false> value, thus indicating to the system
+that it will not modify data passing through.
+
+=back
+
+=head1 SEE ALSO
+
+L<HTTP::Proxy>, L<HTTP::Proxy::BodyFilter>.
 
 =head1 AUTHOR
 
@@ -49,7 +75,7 @@ Philippe "BooK" Bruhat, E<lt>book@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2003-2004, Philippe Bruhat
+Copyright 2003-2006, Philippe Bruhat.
 
 =head1 LICENSE
 
@@ -58,4 +84,3 @@ the same terms as Perl itself.
 
 =cut
 
-1;
